<?php
session_start();
include('mysqli_connect.php');

// Pagination logic
$page = isset($_GET['page']) ? (int)$_GET['page'] : 1;
$limit = 5; // Number of posts per page
$offset = ($page - 1) * $limit;

// Sorting logic
$order_by = isset($_GET['sort']) && in_array($_GET['sort'], ['blogpost_title', 'blogpost_timestamp']) 
    ? $_GET['sort'] 
    : 'blogpost_timestamp';

// Fetch blog posts
$query = "SELECT blogposts.*, users.first_name, users.last_name FROM blogposts 
          JOIN users ON blogposts.user_id = users.user_id 
          ORDER BY $order_by DESC LIMIT $limit OFFSET $offset";
$result = mysqli_query($dbc, $query);

// Get total number of posts for pagination
$total_query = "SELECT COUNT(*) AS total FROM blogposts";
$total_result = mysqli_query($dbc, $total_query);
$total = mysqli_fetch_assoc($total_result)['total'];
$total_pages = ceil($total / $limit);
?>
<!DOCTYPE html>
<html>
<head>
    <link rel="stylesheet" href="style.css">
</head>
<body>
<?php include 'navbar.php'; ?>
<div class="container">
    <h1>Blog Posts</h1>
    <?php if (mysqli_num_rows($result) > 0): ?>
        <?php while ($row = mysqli_fetch_assoc($result)): ?>
            <div>
                <h2><?= htmlspecialchars($row['blogpost_title']) ?></h2>
                <p><?= htmlspecialchars($row['blogpost_body']) ?></p>
                <small>By <?= htmlspecialchars($row['first_name']) ?> <?= htmlspecialchars($row['last_name']) ?> on <?= htmlspecialchars($row['blogpost_timestamp']) ?></small>
                <br>
                <a href="viewcomments.php?blogpost_id=<?= $row['blogpost_id'] ?>">View Comments</a>
                <?php if (isset($_SESSION['user_id']) && $_SESSION['is_admin']): ?>
                    <a href="update.php?blogpost_id=<?= $row['blogpost_id'] ?>">Update</a>
                    <a href="delete.php?blogpost_id=<?= $row['blogpost_id'] ?>">Delete</a>
                <?php endif; ?>
            </div>
        <?php endwhile; ?>
        <div class="pagination">
            <?php for ($i = 1; $i <= $total_pages; $i++): ?>
                <a href="index.php?page=<?= $i ?>"><?= $i ?></a>
            <?php endfor; ?>
        </div>
    <?php else: ?>
        <p>No blog posts available. <?php if (isset($_SESSION['is_admin']) && $_SESSION['is_admin']): ?> <a href="newblogpost.php">Add a new post</a>.<?php endif; ?></p>
    <?php endif; ?>
</div>
</body>
</html>
