<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>My Form Page</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            margin: 20px;
        }
        form {
            width: 500px;
            margin: 0 auto;
        }
        label {
            display: block;
            margin-top: 10px;
        }
        input, select, textarea {
            width: 100%;
            padding: 8px;
            margin-top: 5px;
        }
        input[type="checkbox"], input[type="radio"] {
            width: auto;
        }
        .submit-button {
            width: 100%;
            padding: 10px;
            background-color: #4CAF50;
            color: white;
            border: none;
            cursor: pointer;
            margin-top: 20px;
        }
        .submit-button:hover {
            background-color: #45a049;
        }
        .error {
            color: red;
        }
    </style>
</head>
<body>

<h2>Website Registration Form</h2>
<p>This is a website registration form.</p>

<?php
// Define variables and initialize with empty values
$firstNameErr = $lastNameErr = $emailErr = $dateErr = $genderErr = "";
$firstName = $lastName = $email = $date = $gender = $comments = "";
$interests = [];

if ($_SERVER["REQUEST_METHOD"] == "POST") {
    $valid = true;

    // Validate First Name
    if (empty($_POST["firstname"])) {
        $firstNameErr = "First name is required";
        $valid = false;
    } else {
        $firstName = test_input($_POST["firstname"]);
    }

    // Validate Last Name
    if (empty($_POST["lastname"])) {
        $lastNameErr = "Last name is required";
        $valid = false;
    } else {
        $lastName = test_input($_POST["lastname"]);
    }

    // Validate Email
    if (empty($_POST["email"])) {
        $emailErr = "Email is required";
        $valid = false;
    } else {
        $email = test_input($_POST["email"]);
        if (!filter_var($email, FILTER_VALIDATE_EMAIL)) {
            $emailErr = "Invalid email format";
            $valid = false;
        }
    }

    // Validatng the Date
    if (empty($_POST["day"]) || empty($_POST["month"]) || empty($_POST["year"])) {
        $dateErr = "Please fill out the complete date";
        $valid = false;
    } else {
        $day = $_POST["day"];
        $month = $_POST["month"];
        $year = $_POST["year"];
        
        // Validate if the date is correct
        if (!checkdate($month, $day, $year)) {
            $dateErr = "Invalid date. Please check February!";
            $valid = false;
        } else {
            $date = "$year-$month-$day";
        }
    }

    // Validate Gender
    if (empty($_POST["gender"])) {
        $genderErr = "Gender is required";
        $valid = false;
    } else {
        $gender = test_input($_POST["gender"]);
    }

    // Comments and Interests
    $comments = isset($_POST["comments"]) ? test_input($_POST["comments"]) : "";
    $interests = isset($_POST["interests"]) ? $_POST["interests"] : [];

    // If all validations pass, you can proceed with form submission logic
    if ($valid) {
        echo "<p style='color: green;'>Form submitted successfully!</p>";
        // Insert form data processing logic (e.g., storing in a database)
    }
}

// Function to sanitize user input
function test_input($data) {
    return htmlspecialchars(stripslashes(trim($data)));
}

echo "firstname : $firstName";
     echo "lastname : $lastName<BR>";
     echo "email : $email<BR>";
     echo "date : $date<BR>";
     echo "gender : $gender<BR>";
     echo "comments : $comments<BR>";
?>

<form method="post" action="<?php echo htmlspecialchars($_SERVER["PHP_SELF"]);?>">

    <!-- First Name -->
    <label for="firstname">First Name:</label>
    <input type="text" id="firstname" name="firstname" value="">
    <span class="error"><?php echo $firstNameErr; ?></span>

    <!-- Last Name -->
    <label for="lastname">Last Name:</label>
    <input type="text" id="lastname" name="lastname" value="">
    <span class="error"><?php echo $lastNameErr; ?></span>

    <!-- Email -->
    <label for="email">Email:</label>
    <input type="text" id="email" name="email" value="">
    <span class="error"><?php echo $emailErr; ?></span>

    <!-- Date of Birth -->
    <label>Date of Birth:</label>
    <select name="month">
        <option value="1" <?php if(isset($_POST['month']) && $_POST['month'] == 1) echo 'selected'; ?>>January</option>
        <option value="2" <?php if(isset($_POST['month']) && $_POST['month'] == 2) echo 'selected'; ?>>February</option>
        <option value="3" <?php if(isset($_POST['month']) && $_POST['month'] == 3) echo 'selected'; ?>>March</option>
        <option value="4" <?php if(isset($_POST['month']) && $_POST['month'] == 4) echo 'selected'; ?>>April</option>
        <option value="5" <?php if(isset($_POST['month']) && $_POST['month'] == 5) echo 'selected'; ?>>May</option>
        <option value="6" <?php if(isset($_POST['month']) && $_POST['month'] == 6) echo 'selected'; ?>>June</option>
        <option value="7" <?php if(isset($_POST['month']) && $_POST['month'] == 7) echo 'selected'; ?>>July</option>
        <option value="8" <?php if(isset($_POST['month']) && $_POST['month'] == 8) echo 'selected'; ?>>August</option>
        <option value="9" <?php if(isset($_POST['month']) && $_POST['month'] == 9) echo 'selected'; ?>>September</option>
        <option value="10" <?php if(isset($_POST['month']) && $_POST['month'] == 10) echo 'selected'; ?>>October</option>
        <option value="11" <?php if(isset($_POST['month']) && $_POST['month'] == 11) echo 'selected'; ?>>November</option>
        <option value="12" <?php if(isset($_POST['month']) && $_POST['month'] == 12) echo 'selected'; ?>>December</option>
    </select>

    <input type="number" name="day" placeholder="Day" min="1" max="31" value="">
    <input type="number" name="year" placeholder="Year" min="1900" max="2024" value="<?php echo isset($_POST['year']) ? $_POST['year'] : ''; ?>">
    <span class="error"><?php echo $dateErr; ?></span>

    <!-- Gender -->
    <label>Gender:</label>
    <input type="radio" name="gender" value="M" <?php if (isset($gender) && $gender == "M") echo "checked"; ?>> Male
    <input type="radio" name="gender" value="F" <?php if (isset($gender) && $gender == "F") echo "checked"; ?>> Female
    <span class="error"><?php echo $genderErr; ?></span>

    <!-- Comments -->
    <label for="comments">Comments:</label>
    <textarea id="comments" name="comments" rows="4" cols="50"><?php echo $comments; ?></textarea>

    <!-- Interests -->
    <label>Interests:</label>
    <input type="checkbox" name="interests[]" value="IT" <?php if (in_array("IT", $interests)) echo "checked"; ?>> IT
    <input type="checkbox" name="interests[]" value="Art" <?php if (in_array("Art", $interests)) echo "checked"; ?>> Art
    <input type="checkbox" name="interests[]" value="Science" <?php if (in_array("Science", $interests)) echo "checked"; ?>> Science

    <!-- Submit Button -->
    <input type="submit" class="submit-button" value="Submit">

</form>
</body>
</html>
