<?php
// Include the database connection
include 'includes/mysqli.php';

// Start session
session_start();

// Initialize filters
$search = isset($_GET['search']) ? trim($_GET['search']) : '';
$type = isset($_GET['type']) ? trim($_GET['type']) : '';
$min_price = isset($_GET['min_price']) ? (float) $_GET['min_price'] : 0;
$max_price = isset($_GET['max_price']) ? (float) $_GET['max_price'] : PHP_INT_MAX;

// Build the query
$query = "SELECT * FROM properties WHERE status = 'active'";
$params = [];
$types = '';

// Add filters to the query
if (!empty($search)) {
    $query .= " AND (title LIKE ? OR location LIKE ?)";
    $params[] = "%$search%";
    $params[] = "%$search%";
    $types .= 'ss';
}
if (!empty($type)) {
    $query .= " AND type = ?";
    $params[] = $type;
    $types .= 's';
}
if ($min_price > 0) {
    $query .= " AND price >= ?";
    $params[] = $min_price;
    $types .= 'd';
}
if ($max_price < PHP_INT_MAX) {
    $query .= " AND price <= ?";
    $params[] = $max_price;
    $types .= 'd';
}

// Order properties by creation date
$query .= " ORDER BY created_at DESC";

// Prepare and execute the query
$stmt = $conn->prepare($query);
if (!empty($params)) {
    $stmt->bind_param($types, ...$params);
}
$stmt->execute();
$properties = $stmt->get_result();
$stmt->close();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Explore Properties</title>
    <link rel="stylesheet" href="assets/css/style.css">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css">
</head>
<body>
    <!-- Navigation Bar -->
    <nav class="navbar navbar-expand-lg">
        <div class="container">
            <a class="navbar-brand" href="index.php">
                <img src="assets/images/logo.png" alt="Peterson Real Estate">
            </a>
            <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav" aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
                <span class="navbar-toggler-icon"></span>
            </button>
            <div class="collapse navbar-collapse" id="navbarNav">
                <ul class="navbar-nav ms-auto">
                    <li class="nav-item"><a class="nav-link" href="index.php">Home</a></li>
                    <?php if (isset($_SESSION['user_id'])): ?>
                        <li class="nav-item"><a class="nav-link" href="dashboard/seller.php">Dashboard</a></li>
                        <li class="nav-item"><a class="nav-link" href="logout.php">Logout</a></li>
                    <?php else: ?>
                        <li class="nav-item"><a class="nav-link" href="login.php">Login</a></li>
                        <li class="nav-item"><a class="nav-link" href="register.php">Register</a></li>
                    <?php endif; ?>
                </ul>
            </div>
        </div>
    </nav>

    <!-- Filters -->
    <div class="container mt-5">
        <h1 class="mb-4">Explore Properties</h1>
        <form method="GET" class="row g-3 mb-4">
            <div class="col-md-4">
                <input type="text" name="search" class="form-control" placeholder="Search by title or location" value="<?= htmlspecialchars($search) ?>">
            </div>
            <div class="col-md-2">
                <select name="type" class="form-control">
                    <option value="">All Types</option>
                    <option value="Sale" <?= $type === 'Sale' ? 'selected' : '' ?>>Sale</option>
                    <option value="Rent" <?= $type === 'Rent' ? 'selected' : '' ?>>Rent</option>
                </select>
            </div>
            <div class="col-md-2">
                <input type="number" name="min_price" class="form-control" placeholder="Min Price" value="<?= htmlspecialchars($min_price) ?>">
            </div>
            <div class="col-md-2">
                <input type="number" name="max_price" class="form-control" placeholder="Max Price" value="<?= htmlspecialchars($max_price) ?>">
            </div>
            <div class="col-md-2">
                <button type="submit" class="btn btn-primary w-100">Filter</button>
            </div>
        </form>

        <!-- Properties List -->
        <div class="row">
            <?php if ($properties->num_rows > 0): ?>
                <?php while ($property = $properties->fetch_assoc()): ?>
                    <div class="col-md-4 mb-4">
                        <div class="card">
                            <img src="assets/house-pictures/<?= htmlspecialchars(explode(',', $property['images'])[0]) ?>" alt="Property Image" class="card-img-top">
                            <div class="card-body">
                                <h5 class="card-title"><?= htmlspecialchars($property['title']) ?></h5>
                                <p class="card-text"><?= htmlspecialchars($property['location']) ?></p>
                                <p class="text-muted">$<?= number_format($property['price'], 2) ?></p>
                                <p class="text-muted small">Listed on: <?= date("F j, Y", strtotime($property['created_at'])) ?></p>
                                <a href="property_details.php?id=<?= $property['id'] ?>" class="btn btn-primary btn-sm">View Details</a>
                                <?php if (isset($_SESSION['user_id'])): ?>
                                    <a href="save_property.php?id=<?= $property['id'] ?>" class="btn btn-outline-success btn-sm">Save</a>
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>
                <?php endwhile; ?>
            <?php else: ?>
                <p>No properties found. Try adjusting your filters.</p>
            <?php endif; ?>
        </div>
    </div>
</body>
</html>
